AppListStrings class

Constructors

AppListStrings({String pageTitle = 'Our Apps', String emptyTitle = 'No apps yet', String emptySubtitle = 'Check back later for more apps from this developer.', String openStore = 'Open', String loadError = 'Failed to load apps.'})
const

Properties

emptySubtitle String
final
emptyTitle String
final
hashCode int
The hash code for this object.
no setterinherited
loadError String
final
openStore String
final
pageTitle String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited