AppListStrings constructor

const AppListStrings({
  1. String pageTitle = 'Our Apps',
  2. String emptyTitle = 'No apps yet',
  3. String emptySubtitle = 'Check back later for more apps from this developer.',
  4. String openStore = 'Open',
  5. String loadError = 'Failed to load apps.',
})

Implementation

const AppListStrings({
  this.pageTitle = 'Our Apps',
  this.emptyTitle = 'No apps yet',
  this.emptySubtitle = 'Check back later for more apps from this developer.',
  this.openStore = 'Open',
  this.loadError = 'Failed to load apps.',
});