SmartLinksAppItem class

Constructors

SmartLinksAppItem({required int id, required String name, required String slug, String? googlePlayUrl, String? appStoreUrl, String? iconUrl, String? description, String? shareLink})
const
SmartLinksAppItem.fromJson(Map<String, dynamic> json)
factory

Properties

appStoreUrl String?
final
description String?
final
googlePlayUrl String?
final
hashCode int
The hash code for this object.
no setterinherited
iconUrl String?
final
id int
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
final
slug String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited